@@ -24,10 +24,9 @@ AWS_CONFIG_PATH = f'{Path.home()}/.aws/config'
 AWS_CREDENTIAL_PATH = f'{Path.home()}/.aws/credentials'
 AWS_SSO_CACHE_PATH = f'{Path.home()}/.aws/sso/cache'
 AWS_DEFAULT_REGION = 'us-west-1'
+CURRENT_REGION = os.getenv('AWS_REGION')
 
-try: 
-    CURRENT_REGION = os.getenv('AWS_REGION')
-except: 
+if not CURRENT_REGION:
     current_session = boto3.session.Session()
     CURRENT_REGION = current_session.region_name
 
@@ -175,8 +174,7 @@ def _sso_switch():
     profile = _add_prefix(_select_profile())
     profile_opts = _get_aws_profile(profile)
     profile_name = profile.split(' ')[1]
-    output = '''
-Please execute below commands:
+    source_value = '''
 
 export AWS_ENVS={0}
 export AWS_REGION={1}
@@ -187,9 +185,17 @@ export TF_VAR_aws_region={1}
 export TF_VAR_bucket_name={0}-terraform-state-{2}
 export TF_VAR_cluster_name={0}
 export AWS_DEFAULT_REGION={1}
-export PS1="{0} $ "
+export PS1=\\"{0} \$ \\"
 aws eks --region {1} update-kubeconfig --name {0}
     '''.format(profile_name.split('_')[0], profile_opts['region'], profile_opts['sso_account_id'], profile_name)
+    os.system('echo "{}" > ~/.aws_env'.format(source_value))
+    output = '''
+Please execute following command:
+
+\033[33m
+source ~/.aws_env
+\033[0m
+'''
     print(output)
     _set_profile_credentials(profile)
 
